//File modified by @CrisXolt.
#include "ShaderConstants.fxh"

struct VS_Input
{
    float3 position : POSITION;
    float4 color : COLOR;
#ifdef INSTANCEDSTEREO
	uint instanceID : SV_InstanceID;
#endif
};


struct PS_Input
{
    float4 position : SV_Position;
    float4 color : COLOR;
#ifdef GEOMETRY_INSTANCEDSTEREO
	uint instanceID : SV_InstanceID;
#endif
#ifdef VERTEXSHADER_INSTANCEDSTEREO
	uint renTarget_id : SV_RenderTargetArrayIndex;
#endif
};

ROOT_SIGNATURE
void main(in VS_Input VSInput, out PS_Input PSInput)
{
#ifdef INSTANCEDSTEREO
	int i = VSInput.instanceID;
	PSInput.position = mul( WORLDVIEWPROJ_STEREO[i], float4( VSInput.position, 1 ) );
#else
	PSInput.position = mul(WORLDVIEWPROJ, float4(VSInput.position, 1));
#endif
#ifdef GEOMETRY_INSTANCEDSTEREO
	PSInput.instanceID = VSInput.instanceID;
#endif 
#ifdef VERTEXSHADER_INSTANCEDSTEREO
	PSInput.renTarget_id = VSInput.instanceID;
#endif

		float SST = clamp((CURRENT_COLOR.b-0.15)*1.1764706,0.0,1.0);

		float TD = (SST);
		float TS = (0.5-abs(0.5-SST));
		float TN = (1.0-TD);
		float WR = (1.0-clamp(3.34*(FOG_CONTROL.y-0.7),0.0,1.0));

		float4 D = float4(0.025, 0.025, 0.025, 1.0);
		float4 N = float4(1.125, 1.125, 1.125, 1.0);
		float4 S = float4(0.75, 0.875, 1.25, 5.0);
		float4 R = float4(0.5, 0.5, 0.5, 1.0);

		D = D * TD;
		N = N * TN;
		S = S * TS;
		R = R * WR;

		float4 DN = (1.0-N.a)*D+N.a*N;
		float4 DS = (1.0-S.a)*DN+S.a*S;
		float4 DR = (1.0-R.a)*DS+R.a*R;

    PSInput.color = lerp( CURRENT_COLOR * DR, FOG_COLOR, VSInput.color.r );
}